<template>
  <div>
    <el-dialog
      :title="`${contractObj.contractName}合同详情`"
      :visible="visible"
      width="60%"
      top="20vh"
      :before-close="handleClose"
    >
      <div class="contractDetails">
        <el-descriptions :column="3" border>
          <template slot="extra"></template>
          <el-descriptions-item>
            <template slot="label"> 合同编码</template>
            {{ contractObj.contractCode }}
          </el-descriptions-item>
          <el-descriptions-item>
            <template slot="label"> 合同名称</template>
            {{ contractObj.contractName }}
          </el-descriptions-item>
          <el-descriptions-item>
            <template slot="label"> 责任人</template>
            {{ contractObj.personLiable }}
          </el-descriptions-item>
          <el-descriptions-item>
            <template slot="label"> 合同签订时间</template>
            {{ contractObj.signDate }}
          </el-descriptions-item>
          <el-descriptions-item>
            <template slot="label"> 合同类型</template>
            {{
            contractObj.contractType == 1
            ? '采购合同'
            : contractObj.contractType == 2
            ? '建设合同'
            : '运维合同'
            }}
          </el-descriptions-item>
          <el-descriptions-item>
            <template slot="label"> 合同开始时间</template>
            {{ contractObj.startDate }}
          </el-descriptions-item>
          <el-descriptions-item>
            <template slot="label"> 合同结束时间</template>
            {{ contractObj.endDate }}
          </el-descriptions-item>
          <el-descriptions-item>
            <template slot="label"> 合同状态</template>
            <div
              class="changColor"
              :class="{contractStatus: contractObj.contractStatus == 1}"
            >
              {{ contractObj.contractStatus == 1 ? '进行中' : '已完成' }}
            </div>
          </el-descriptions-item>
          <el-descriptions-item>
            <template slot="label"> 供应商</template>
            {{ contractObj.companyName }}
          </el-descriptions-item>
          <el-descriptions-item>
            <template slot="label"> 附件下载</template>
            <div class="checkboxFor" v-if="isAccessory">
              <el-checkbox-group v-model="checkList">
                <el-checkbox
                  :label="item.name"
                  v-for="item in fileList"
                  :key="item.bizId"
                ></el-checkbox>
              </el-checkbox-group>
              <el-button
                type="warning"
                size="mini"
                @click="downloadText"
                v-if="isAccessory"
              >点击下载
              </el-button
              >
            </div>
            <span v-if="!isAccessory">无</span>
          </el-descriptions-item>
        </el-descriptions>
      </div>
    </el-dialog>
  </div>
</template>
<script>
import equipmentManage from '@/api/device/equipmentManage.js'
import req from '@/request.js'
import utils from '@/hotent-ui-util.js'
import {TableMixin} from '@/mixins/tableMixin'
import contractManage from '@/api/device/contractManage.js'
import {mapState} from 'vuex'

export default {
  name: 'relatedDeviceDialog',
  components: {},
  mixins: [TableMixin],
  data() {
    return {
      loading: false,
      visible: false,
      checkList: [],
      fileList: [], //附件数据
      contractObj: {}, //表格数据
      relationList: {
        deviceId: '',
        contracts: []
      },
      queryParmas: {
        pageBean: {
          page: 1,
          pageSize: -1,
          showTotal: true
        },
        querys: [
          {
            group: 'main',
            operation: 'EQUAL',
            property: 'biz_id_',
            relation: 'AND',
            value: ''
          }
        ]
      },
      isAccessory: true
    }
  },
  computed: mapState({
    header: (state) => {
      return {
        Authorization: `Bearer ${state.login.currentUser.token}`
      }
    }
  }),
  methods: {
    addDetail(row) {
      this.contractObj = row
      this.visible = true
      this.queryParmas.querys[0].value = row.id
      this.fileList = []
      contractManage.queryFile(this.queryParmas, (rep) => {
        if (rep.rows) {
          rep.rows.forEach((p) => {
            let arr = {
              bizId: p.id,
              name: p.fileName + '.' + p.extensionName
            }
            this.fileList.push(arr)
          })
          console.log(this.fileList)
        }
        if (this.fileList.length == 0) {
          this.isAccessory = false
        }
      })
    },
    loadData() {
      let data = {
        pageBean: {
          page: 1,
          pageSize: -1,
          showTotal: true
        },
        params: {}
      }
      contractManage.contractQuery(data).then((res) => {
        this.loading = true
        this.tableData = res.rows
      })
    },
    getAsyncData(ids) {
      return new Promise((resolve, reject) => {
        req.get(window.context.form + '/file/v1/downloadFile?fileId=' + ids)
      })
    },
    //附件下载
    downloadText() {
      if (this.fileList.length == 0) {
        this.$message.error('没有附件内容')
      } else {
        if (this.checkList.length) {
          this.fileList.forEach((item) => {
            this.checkList.forEach((ii) => {
              if (item.name == ii) {
                this.isAccessory = true
                return this.getAsyncData(item.bizId)
              }
            })
          })
        } else {
          this.$message.error('请选择你要下载的附件')
        }
      }
    },
    handleClose() {
      this.visible = false
    }
  }
}
</script>
<style lang="scss" scoped>
.contractDetails {
  padding: 12px 16px;
  width: 100%;
  box-sizing: border-box;
}

.changColor {
  color: red;
}

.contractStatus {
  color: blue !important;
}

.margin-top {
  margin-top: 16px;
}

::v-deep .el-dialog {
  height: 350px !important;
}

.el-dialog__wrapper {
  height: 100% !important;
}

.el-transfer-panel {
  height: 100% !important;
  width: 100% !important;
}

::v-deep .el-dialog__body {
  padding: 0px;
  height: 600px !important;
  overflow-y: auto !important;
  overflow-x: hidden;
}

::v-deep .el-table::before {
  height: 0;
}

.el-select-dropdown__item span {
  color: rgb(51, 51, 51) !important;
}

.el-select-dropdown__item {
  color: #9a9a9a !important;
}

.el-select-dropdown__item.hover,
.el-select-dropdown__item:hover {
  background: #f5f7fa;
}

.el-card__body {
  width: 100% !important;
  height: 100% !important;
}

.custom-tree-node {
  box-sizing: border-box;
  display: flex;
  justify-content: space-around !important;
}

.el-card {
  width: 100% !important;
  height: 100% !important;
}

.el-main {
  width: 100% !important;
  height: 100% !important;
}

.sampling {
  ::v-deep .el-dialog__body {
    padding: 30px 20px 0 20px;
  }
}

::-webkit-scrollbar {
  background: #fff !important;
}

.custom-tree-node {
  font-size: 12px;
}

.el-popover {
  min-width: 35px !important;
  padding: 5px 0 !important;
}

.line {
  display: block !important;
  height: 1px !important;
  background: #ccc !important;
}

.checkbox-group {
  height: 454px !important;
}

.checkboxFor {
  display: flex;
  justify-content: space-between;
  flex-wrap: wrap;
}
</style>
